@@ -1,4 +1,3 @@
-import requests
 from .letter import Letter
 from ..exceptions import NotSetEmail
 from ..mail import Mail
@@ -25,8 +24,8 @@ class InboxKitten(Mail):
         if not self._email:
             raise NotSetEmail()
 
-        r = requests.get(f'https://inboxkitten.com/api/v1/mail/list?recipient={self._email}', proxies=self._proxies)
+        r = self._s.get(f'https://inboxkitten.com/api/v1/mail/list?recipient={self._email}')
         if r.status_code == 200:
             return [Letter(__letter['storage']['url'], __letter['message']['headers'], __letter['timestamp'],
-                           self._proxies) for __letter in r.json()]
+                           self._s) for __letter in r.json()]
         return []
